# uplogic
A logic extention module for [UPBGE](https://github.com/UPBGE/upbge) containing utility functions, wrappers and the code to run logic nodes.

## license
This project is provided under the terms of _[GNU General Public License v2 (GPLv2)](LICENSE)_.